using System;
using fomm.Scripting;
using System.IO;
using System.Windows.Forms;
using System.Drawing;

    class Script : BaseScript
    {
        // proceed with installation?
        public static bool install = false;

        public static Form InstallForm;
        public static PictureBox BackgroundPicture;
        public static Panel OptionsPanel;
        public static Label DisableMinigamesLabel;
        public static Label EnableMinigamesLabel;
        public static Label LockbashOnlyLabel;
        public static Label InstallReadmeLabel;
        public static Label OptionsLabel;
        public static Label TitleLabel;
        public static RadioButton DisableMinigamesRadioButton;
        public static RadioButton EnableMinigamesRadioButton;
        public static RadioButton LockbashOnlyRadioButton;
        public static CheckBox InstallReadmeCheckBox;
        public static Button InstallButton;
        public static Button CancelInstallButton;

        public static Image GetImageFromFomod(string filename)
        {
            byte[] data = GetFileFromFomod(filename);
            MemoryStream s = new MemoryStream(data);
            Image img = Image.FromStream(s);
            s.Close();
            return img;
        }

        public static void SaveFomodFileAs(string filename, string newFilename)
        {
            byte[] data = GetFileFromFomod(filename);
            GenerateDataFile(newFilename, data);
        }

        public static void CreateInstallForm()
        {
            InstallForm = CreateCustomForm();

            // center, resize and change border of form
            InstallForm.FormBorderStyle = FormBorderStyle.Fixed3D;
            InstallForm.StartPosition = FormStartPosition.CenterScreen;
            InstallForm.Size = new Size(496, 600);

            // place background picture box
            BackgroundPicture = new PictureBox();
            BackgroundPicture.Location = new Point(0, 0);
            BackgroundPicture.Size = new Size(496, 600);

            // load picture file from .fomod and stream into picture box
            BackgroundPicture.Image = GetImageFromFomod("fomod/gashingteeth.jpg");

            TitleLabel = new Label();
            TitleLabel.Text = "Zumbs' Overhauled Real-Time Security";
            TitleLabel.Font = new Font("Times New Roman", 16, FontStyle.Bold);
            TitleLabel.ForeColor = Color.Snow;
            TitleLabel.BackColor = Color.Transparent;
            TitleLabel.Location = new Point(45, 30);
            TitleLabel.TextAlign = ContentAlignment.MiddleCenter;
            TitleLabel.AutoSize = true;

            // options panel
            OptionsPanel = new Panel();
            OptionsPanel.Location = new Point(266, 110);
            OptionsPanel.Size = new Size(210, 160);
            OptionsPanel.BackColor = Color.WhiteSmoke;
            OptionsPanel.BorderStyle = BorderStyle.FixedSingle;

            // options label
            OptionsLabel = new Label();
            OptionsLabel.Text = "Options";
            OptionsLabel.Font = new Font("Arial", 10, FontStyle.Bold);
            OptionsLabel.Location = new Point(3, 6);
            OptionsLabel.AutoSize = true;
            OptionsLabel.Controls.Add(DisableMinigamesLabel);

            // disable minigame label
            DisableMinigamesLabel = new Label();
            DisableMinigamesLabel.Text = "Disable Minigames";
            DisableMinigamesLabel.Location = new Point(27, 36);
            DisableMinigamesLabel.AutoSize = true;

            // disable minigame radiobutton
            DisableMinigamesRadioButton = new RadioButton();
            DisableMinigamesRadioButton.Checked = true;
            DisableMinigamesRadioButton.Location = new Point(5, 33);
            DisableMinigamesRadioButton.Size = new Size(20, 20);

            // enable minigame
            EnableMinigamesLabel = new Label();
            EnableMinigamesLabel.Text = "Enable minigames";
            EnableMinigamesLabel.Location = new Point(27, 59);
            EnableMinigamesLabel.AutoSize = true;

            // enable minigame
            EnableMinigamesRadioButton = new RadioButton();
            EnableMinigamesRadioButton.Checked = false;
            EnableMinigamesRadioButton.Location = new Point(5, 56);
            EnableMinigamesRadioButton.Size = new Size(20, 20);

            // lockbash only label
            LockbashOnlyLabel = new Label();
            LockbashOnlyLabel.Text = "Lockbash only, enable minigames";
            LockbashOnlyLabel.Location = new Point(27, 82);
            LockbashOnlyLabel.AutoSize = true;

            // lockbash only radiobutton
            LockbashOnlyRadioButton = new RadioButton();
            LockbashOnlyRadioButton.Checked = false;
            LockbashOnlyRadioButton.Location = new Point(5, 79);
            LockbashOnlyRadioButton.Size = new Size(20, 20);

            // copy readme label
            InstallReadmeLabel = new Label();
            InstallReadmeLabel.Text = "Copy readme to Data folder";
            InstallReadmeLabel.Location = new Point(27, 105);
            InstallReadmeLabel.AutoSize = true;

            // copy readme checkbox
            InstallReadmeCheckBox = new CheckBox();
            InstallReadmeCheckBox.Checked = true;
            InstallReadmeCheckBox.Location = new Point(5, 102);
            InstallReadmeCheckBox.Size = new Size(20, 20);

            // install button
            InstallButton = new Button();
            InstallButton.Text = "Install";
            InstallButton.BackColor = Color.Silver;
            InstallButton.Location = new Point(5, 135);
            InstallButton.Size = new Size(100, 23);

            // cancel button
            CancelInstallButton = new Button();
            CancelInstallButton.Text = "Cancel";
            CancelInstallButton.BackColor = Color.Silver;
            CancelInstallButton.Location = new Point(105, 135);
            CancelInstallButton.Size = new Size(100, 23);

            // build form
            InstallForm.Controls.Add(BackgroundPicture);
            BackgroundPicture.Controls.Add(OptionsPanel);
            BackgroundPicture.Controls.Add(TitleLabel);
            OptionsPanel.Controls.Add(OptionsLabel);
            OptionsPanel.Controls.Add(DisableMinigamesLabel);
            OptionsPanel.Controls.Add(DisableMinigamesRadioButton);
            OptionsPanel.Controls.Add(EnableMinigamesLabel);
            OptionsPanel.Controls.Add(EnableMinigamesRadioButton);
            OptionsPanel.Controls.Add(LockbashOnlyLabel);
            OptionsPanel.Controls.Add(LockbashOnlyRadioButton);
            OptionsPanel.Controls.Add(InstallReadmeLabel);
            OptionsPanel.Controls.Add(InstallReadmeCheckBox);
            OptionsPanel.Controls.Add(InstallButton);
            OptionsPanel.Controls.Add(CancelInstallButton);

            // attach event handlers
            AttachHandlers();
        }

        public static void AttachHandlers()
        {
            //Attach a handler that will fire when the apply button is clicked 
            InstallButton.Click += delegate(object sender, EventArgs args)
            {
                install = true;
                InstallForm.Close();
            };

            CancelInstallButton.Click += delegate(object sender, EventArgs args)
            {
                install = false;
                InstallForm.Close();
            };
        }

        public static void InstallZORTS()
        {
            InstallFileFromFomod("ZORTS.ini");
            InstallFileFromFomod("Zumbs'_Overhauled_Real_Time_Security.bsa");
            if (DisableMinigamesRadioButton.Checked)
            {
                InstallFileFromFomod("Zumbs'_Overhauled_Real_Time_Security.esp");
            }
            else if (EnableMinigamesRadioButton.Checked)
            {
                SaveFomodFileAs("Zumbs'_Overhauled_Real_Time_Security_minigames_enabled.esp", "Zumbs'_Overhauled_Real_Time_Security.esp");
            }
            else if (LockbashOnlyRadioButton.Checked)
            {
                SaveFomodFileAs("Zumbs'_Overhauled_Real_Time_Security_lockbash_only.esp", "Zumbs'_Overhauled_Real_Time_Security.esp");
            }
            SetPluginActivation("Zumbs'_Overhauled_Real_Time_Security.esp", true);
            if (InstallReadmeCheckBox.Checked)
            {
                // annoying that FOMM renames my readmes ...
                InstallFileFromFomod("Readme - Zumbs'_Overhauled_Real_Time_Security_v1.txt");
            }
        }

        public static bool OnActivate()
        {
            Version requiredFose = new Version(0, 1, 1, 9);
            if (GetFoseVersion() < requiredFose)
            {
                // handle wrong fose version
                MessageBox("This mod requires FOSE v " + requiredFose + " or higher. You have " + GetFoseVersion() + ". Please update from http://silverlock.org");
                return false;
            }
            else
            {
                // build and show form
                CreateInstallForm();
                InstallForm.ShowDialog();

                if (install)
                {
                    //Install ZORTS with selected options
                    InstallZORTS();
                }

                return install;
            }
        }
    }